@@ -7,6 +7,7 @@ from ...properties import Property, Filter
 from ...responses import ValidResponse, ErrorResponse, ApiError, ResponseHeaders
 
 from .models.active_directory import ActiveDirectory
+from .models.active_directory_patch import ActiveDirectoryPatch
 from .models.active_directory_post import ActiveDirectoryPost
 from .models.admin import Admin
 from .models.admin_api_token import AdminApiToken
@@ -73,6 +74,7 @@ from .models.directorypolicyexportpost_policies import Directorypolicyexportpost
 from .models.directorypolicypost_policies import DirectorypolicypostPolicies
 from .models.dns import Dns
 from .models.dns_patch import DnsPatch
+from .models.dns_post import DnsPost
 from .models.drive import Drive
 from .models.eradication_config import EradicationConfig
 from .models.eula import Eula
@@ -130,6 +132,7 @@ from .models.page_info import PageInfo
 from .models.performance import Performance
 from .models.pod import Pod
 from .models.pod_array_status import PodArrayStatus
+from .models.pod_eradication_config import PodEradicationConfig
 from .models.pod_patch import PodPatch
 from .models.pod_performance import PodPerformance
 from .models.pod_performance_by_array import PodPerformanceByArray
@@ -147,11 +150,15 @@ from .models.policy_member import PolicyMember
 from .models.policy_member_export import PolicyMemberExport
 from .models.policy_member_export_post import PolicyMemberExportPost
 from .models.policy_member_post import PolicyMemberPost
+from .models.policy_nfs import PolicyNfs
+from .models.policy_nfs_patch import PolicyNfsPatch
+from .models.policy_nfs_post import PolicyNfsPost
 from .models.policy_patch import PolicyPatch
 from .models.policy_post import PolicyPost
 from .models.policy_rule_nfs_client import PolicyRuleNfsClient
 from .models.policy_rule_nfs_client_post import PolicyRuleNfsClientPost
 from .models.policy_rule_quota import PolicyRuleQuota
+from .models.policy_rule_quota_patch import PolicyRuleQuotaPatch
 from .models.policy_rule_quota_post import PolicyRuleQuotaPost
 from .models.policy_rule_smb_client import PolicyRuleSmbClient
 from .models.policy_rule_smb_client_post import PolicyRuleSmbClientPost
@@ -163,6 +170,7 @@ from .models.policy_smb_post import PolicySmbPost
 from .models.policymemberexportpost_members import PolicymemberexportpostMembers
 from .models.policymemberpost_members import PolicymemberpostMembers
 from .models.policyrulenfsclientpost_rules import PolicyrulenfsclientpostRules
+from .models.policyrulequotapatch_rules import PolicyrulequotapatchRules
 from .models.policyrulequotapost_rules import PolicyrulequotapostRules
 from .models.policyrulesmbclientpost_rules import PolicyrulesmbclientpostRules
 from .models.policyrulesnapshotpost_rules import PolicyrulesnapshotpostRules
@@ -171,6 +179,7 @@ from .models.port_common import PortCommon
 from .models.port_initiator import PortInitiator
 from .models.priority_adjustment import PriorityAdjustment
 from .models.protection_group import ProtectionGroup
+from .models.protection_group_eradication_config import ProtectionGroupEradicationConfig
 from .models.protection_group_performance import ProtectionGroupPerformance
 from .models.protection_group_performance_array import ProtectionGroupPerformanceArray
 from .models.protection_group_performance_by_array import ProtectionGroupPerformanceByArray
@@ -293,6 +302,7 @@ def add_properties(model):
 
 CLASSES_TO_ADD_PROPS = [
     ActiveDirectory,
+    ActiveDirectoryPatch,
     ActiveDirectoryPost,
     Admin,
     AdminApiToken,
@@ -359,6 +369,7 @@ CLASSES_TO_ADD_PROPS = [
     DirectorypolicypostPolicies,
     Dns,
     DnsPatch,
+    DnsPost,
     Drive,
     EradicationConfig,
     Eula,
@@ -416,6 +427,7 @@ CLASSES_TO_ADD_PROPS = [
     Performance,
     Pod,
     PodArrayStatus,
+    PodEradicationConfig,
     PodPatch,
     PodPerformance,
     PodPerformanceByArray,
@@ -433,11 +445,15 @@ CLASSES_TO_ADD_PROPS = [
     PolicyMemberExport,
     PolicyMemberExportPost,
     PolicyMemberPost,
+    PolicyNfs,
+    PolicyNfsPatch,
+    PolicyNfsPost,
     PolicyPatch,
     PolicyPost,
     PolicyRuleNfsClient,
     PolicyRuleNfsClientPost,
     PolicyRuleQuota,
+    PolicyRuleQuotaPatch,
     PolicyRuleQuotaPost,
     PolicyRuleSmbClient,
     PolicyRuleSmbClientPost,
@@ -449,6 +465,7 @@ CLASSES_TO_ADD_PROPS = [
     PolicymemberexportpostMembers,
     PolicymemberpostMembers,
     PolicyrulenfsclientpostRules,
+    PolicyrulequotapatchRules,
     PolicyrulequotapostRules,
     PolicyrulesmbclientpostRules,
     PolicyrulesnapshotpostRules,
@@ -457,6 +474,7 @@ CLASSES_TO_ADD_PROPS = [
     PortInitiator,
     PriorityAdjustment,
     ProtectionGroup,
+    ProtectionGroupEradicationConfig,
     ProtectionGroupPerformance,
     ProtectionGroupPerformanceArray,
     ProtectionGroupPerformanceByArray,
