@@ -13,6 +13,7 @@ from .audits_api import AuditsApi
 from .authorization_api import AuthorizationApi
 from .certificates_api import CertificatesApi
 from .connections_api import ConnectionsApi
+from .container_default_protections_api import ContainerDefaultProtectionsApi
 from .controllers_api import ControllersApi
 from .dns_api import DNSApi
 from .directories_api import DirectoriesApi
@@ -39,6 +40,7 @@ from .remote_pods_api import RemotePodsApi
 from .remote_protection_group_snapshots_api import RemoteProtectionGroupSnapshotsApi
 from .remote_protection_groups_api import RemoteProtectionGroupsApi
 from .remote_volume_snapshots_api import RemoteVolumeSnapshotsApi
+from .saml2_sso_api import SAML2SSOApi
 from .smi_s_api import SMISApi
 from .smtp_api import SMTPApi
 from .snmp_agents_api import SNMPAgentsApi
