@@ -46,7 +46,6 @@ def quoteStrings(s):
 # import models into model package
 from .active_directory import ActiveDirectory
 from .active_directory_get_response import ActiveDirectoryGetResponse
-from .active_directory_patch import ActiveDirectoryPatch
 from .active_directory_post import ActiveDirectoryPost
 from .active_directory_response import ActiveDirectoryResponse
 from .admin import Admin
@@ -169,7 +168,6 @@ from .directorypolicypost_policies import DirectorypolicypostPolicies
 from .dns import Dns
 from .dns_get_response import DnsGetResponse
 from .dns_patch import DnsPatch
-from .dns_post import DnsPost
 from .dns_response import DnsResponse
 from .drive import Drive
 from .drive_get_response import DriveGetResponse
@@ -258,13 +256,10 @@ from .page_info import PageInfo
 from .performance import Performance
 from .pod import Pod
 from .pod_array_status import PodArrayStatus
-from .pod_eradication_config import PodEradicationConfig
 from .pod_get_response import PodGetResponse
 from .pod_patch import PodPatch
 from .pod_performance import PodPerformance
 from .pod_performance_by_array import PodPerformanceByArray
-from .pod_performance_by_array_get_response import PodPerformanceByArrayGetResponse
-from .pod_performance_get_response import PodPerformanceGetResponse
 from .pod_performance_replication import PodPerformanceReplication
 from .pod_performance_replication_by_array import PodPerformanceReplicationByArray
 from .pod_performance_replication_by_array_get_response import PodPerformanceReplicationByArrayGetResponse
@@ -295,11 +290,6 @@ from .policy_member_export_response import PolicyMemberExportResponse
 from .policy_member_get_response import PolicyMemberGetResponse
 from .policy_member_post import PolicyMemberPost
 from .policy_member_response import PolicyMemberResponse
-from .policy_nfs import PolicyNfs
-from .policy_nfs_get_response import PolicyNfsGetResponse
-from .policy_nfs_patch import PolicyNfsPatch
-from .policy_nfs_post import PolicyNfsPost
-from .policy_nfs_response import PolicyNfsResponse
 from .policy_patch import PolicyPatch
 from .policy_post import PolicyPost
 from .policy_response import PolicyResponse
@@ -309,7 +299,6 @@ from .policy_rule_nfs_client_post import PolicyRuleNfsClientPost
 from .policy_rule_nfs_client_response import PolicyRuleNfsClientResponse
 from .policy_rule_quota import PolicyRuleQuota
 from .policy_rule_quota_get_response import PolicyRuleQuotaGetResponse
-from .policy_rule_quota_patch import PolicyRuleQuotaPatch
 from .policy_rule_quota_post import PolicyRuleQuotaPost
 from .policy_rule_quota_response import PolicyRuleQuotaResponse
 from .policy_rule_smb_client import PolicyRuleSmbClient
@@ -328,7 +317,6 @@ from .policy_smb_response import PolicySmbResponse
 from .policymemberexportpost_members import PolicymemberexportpostMembers
 from .policymemberpost_members import PolicymemberpostMembers
 from .policyrulenfsclientpost_rules import PolicyrulenfsclientpostRules
-from .policyrulequotapatch_rules import PolicyrulequotapatchRules
 from .policyrulequotapost_rules import PolicyrulequotapostRules
 from .policyrulesmbclientpost_rules import PolicyrulesmbclientpostRules
 from .policyrulesnapshotpost_rules import PolicyrulesnapshotpostRules
@@ -337,9 +325,7 @@ from .port_common import PortCommon
 from .port_get_response import PortGetResponse
 from .port_initiator import PortInitiator
 from .port_initiators_get_response import PortInitiatorsGetResponse
-from .priority_adjustment import PriorityAdjustment
 from .protection_group import ProtectionGroup
-from .protection_group_eradication_config import ProtectionGroupEradicationConfig
 from .protection_group_get_response import ProtectionGroupGetResponse
 from .protection_group_performance import ProtectionGroupPerformance
 from .protection_group_performance_array import ProtectionGroupPerformanceArray
@@ -406,14 +392,6 @@ from .resource_space_get_response import ResourceSpaceGetResponse
 from .resource_space_no_id import ResourceSpaceNoId
 from .resource_space_no_id_get_response import ResourceSpaceNoIdGetResponse
 from .retention_policy import RetentionPolicy
-from .saml2_sso import Saml2Sso
-from .saml2_sso_get_response import Saml2SsoGetResponse
-from .saml2_sso_idp import Saml2SsoIdp
-from .saml2_sso_patch import Saml2SsoPatch
-from .saml2_sso_post import Saml2SsoPost
-from .saml2_sso_response import Saml2SsoResponse
-from .saml2_sso_sp import Saml2SsoSp
-from .saml2_sso_sp_credential import Saml2SsoSpCredential
 from .session import Session
 from .session_get_response import SessionGetResponse
 from .smis import Smis
@@ -498,7 +476,6 @@ from .test_result_get_response import TestResultGetResponse
 from .test_result_response import TestResultResponse
 from .test_result_with_resource import TestResultWithResource
 from .test_result_with_resource_get_response import TestResultWithResourceGetResponse
-from .test_result_with_resource_patch_response import TestResultWithResourcePatchResponse
 from .test_result_with_resource_response import TestResultWithResourceResponse
 from .throttle import Throttle
 from .time_window import TimeWindow
@@ -506,10 +483,6 @@ from .total_item_count_response import TotalItemCountResponse
 from .transfer import Transfer
 from .username import Username
 from .username_response import UsernameResponse
-from .virtual_machine import VirtualMachine
-from .virtual_machine_get_response import VirtualMachineGetResponse
-from .virtual_machine_post import VirtualMachinePost
-from .virtual_machine_response import VirtualMachineResponse
 from .volume import Volume
 from .volume_common import VolumeCommon
 from .volume_diff import VolumeDiff
