@@ -83,7 +83,6 @@ from .array_connection_path import ArrayConnectionPath
 from .array_connection_path_get_response import ArrayConnectionPathGetResponse
 from .array_connection_post import ArrayConnectionPost
 from .array_connection_response import ArrayConnectionResponse
-from .array_eradication_config import ArrayEradicationConfig
 from .array_factory_reset_token import ArrayFactoryResetToken
 from .array_factory_reset_token_get_response import ArrayFactoryResetTokenGetResponse
 from .array_factory_reset_token_response import ArrayFactoryResetTokenResponse
@@ -153,13 +152,10 @@ from .directory_service_smb import DirectoryServiceSmb
 from .dns import Dns
 from .dns_get_response import DnsGetResponse
 from .dns_response import DnsResponse
-from .drive import Drive
-from .drive_get_response import DriveGetResponse
 from .eula import Eula
 from .eula_get_response import EulaGetResponse
 from .eula_response import EulaResponse
 from .eula_signature import EulaSignature
-from .file_info import FileInfo
 from .file_system import FileSystem
 from .file_system_get_response import FileSystemGetResponse
 from .file_system_group_performance import FileSystemGroupPerformance
@@ -225,9 +221,6 @@ from .linkaggregationgroup import Linkaggregationgroup
 from .location_reference import LocationReference
 from .login import Login
 from .login_banner_get_response import LoginBannerGetResponse
-from .logs_async import LogsAsync
-from .logs_async_get_response import LogsAsyncGetResponse
-from .logs_async_response import LogsAsyncResponse
 from .member import Member
 from .member_link import MemberLink
 from .multi_protocol import MultiProtocol
@@ -239,7 +232,6 @@ from .network_interface_response import NetworkInterfaceResponse
 from .nfs import Nfs
 from .nfs_export_policy import NfsExportPolicy
 from .nfs_export_policy_get_response import NfsExportPolicyGetResponse
-from .nfs_export_policy_post import NfsExportPolicyPost
 from .nfs_export_policy_response import NfsExportPolicyResponse
 from .nfs_export_policy_rule import NfsExportPolicyRule
 from .nfs_export_policy_rule_base import NfsExportPolicyRuleBase
@@ -282,7 +274,6 @@ from .permission import Permission
 from .policy import Policy
 from .policy_base import PolicyBase
 from .policy_base_get_response import PolicyBaseGetResponse
-from .policy_base_renameable import PolicyBaseRenameable
 from .policy_base_response import PolicyBaseResponse
 from .policy_file_system_snapshot import PolicyFileSystemSnapshot
 from .policy_file_system_snapshot_get_response import PolicyFileSystemSnapshotGetResponse
